@@ -19,25 +19,25 @@ chknumeric <- function(x, min, max, zero = FALSE, single = FALSE,
          call. = FALSE)
   ##
   if (!missing(min) & missing(max)) {
-    if (zero & min == 0 & any(x <= min))
+    if (zero & min == 0 & any(x <= min, na.rm = TRUE))
       stop("Argument '", name, "' must be positive.",
            call. = FALSE)
-    else if (any(x < min))
+    else if (any(x < min, na.rm = TRUE))
       stop("Argument '", name, "' must be larger equal ",
            min, ".", call. = FALSE)
   }
   ##
   if (missing(min) & !missing(max)) {
-    if (zero & max == 0 & any(x >= max))
+    if (zero & max == 0 & any(x >= max, na.rm = TRUE))
       stop("Argument '", name, "' must be negative.",
            call. = FALSE)
-    else if (any(x > max))
+    else if (any(x > max, na.rm = TRUE))
       stop("Argument '", name, "' must be smaller equal ",
            min, ".", call. = FALSE)
   }
   ##
   if ((!missing(min) & !missing(max)) &&
-      (any(x < min) | any(x > max)))
+      (any(x < min, na.rm = TRUE) | any(x > max, na.rm = TRUE)))
     stop("Argument '", name, "' must be between ",
          min, " and ", max, ".", call. = FALSE)
   ##
