@@ -1,12 +1,14 @@
 format.p <- function(p, lab = FALSE, labval = "p", noblanks = FALSE,
-                     digits = 4) {
+                     digits = 4, zero = TRUE) {
   if (is.null(p))
     return("")
   outdec <- options()$OutDec
   if (lab)
     res <- format(ifelse(is.na(p), paste(labval, "= --"),
-                         ifelse(p < 0.0001,
-                                paste(labval, " < 0", outdec, "0001", sep = ""),
+                         ifelse(p < 1 / 10^digits,
+                                paste(labval, " < 0", outdec,
+                                      paste(rep("0", digits - 1), collapse = ""),
+                                      "1", sep = ""),
                                 paste(paste(labval, " = "),
                                       formatC(round(p, digits), decimal.mark = outdec,
                                               format = "f", digits = digits)
@@ -16,8 +18,10 @@ format.p <- function(p, lab = FALSE, labval = "p", noblanks = FALSE,
                   )
   else
     res <- format(ifelse(is.na(p), "      --",
-                         ifelse(p < 0.0001,
-                                paste("< 0", outdec, "0001", sep = ""),
+                         ifelse(p < 1 / 10^digits,
+                                paste("< 0", outdec,
+                                      paste(rep("0", digits - 1), collapse = ""),
+                                      "1", sep = ""),
                                 paste(" ", formatC(round(p, digits), decimal.mark = outdec,
                                                    format = "f", digits = digits)
                                       )
@@ -27,6 +31,8 @@ format.p <- function(p, lab = FALSE, labval = "p", noblanks = FALSE,
   ##
   if (noblanks)
     res <- gsub(" ", "", res)
+  if (!zero)
+    res <- gsub("0\\.", "\\.", res)
   ##
   res
 }
